@@ -1,6 +1,6 @@
 /*************************************************************************
  *
- * $Id: trionan.h,v 1.2 2002/01/19 15:40:18 breese Exp $
+ * $Id: trionan.h,v 1.3 2002/03/27 16:12:21 veillard Exp $
  *
  * Copyright (C) 2001 Bjorn Reese <breese@users.sourceforge.net>
  *
@@ -23,6 +23,15 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
+
+enum {
+  TRIO_FP_INFINITE,
+  TRIO_FP_NAN,
+  TRIO_FP_NORMAL,
+  TRIO_FP_SUBNORMAL,
+  TRIO_FP_ZERO
+};
+
 /*
  * Return NaN (Not-a-Number).
  */
@@ -49,6 +58,17 @@ TRIO_PUBLIC int trio_isnan(double number);
  */
 TRIO_PUBLIC int trio_isinf(double number);
 
+/*
+ * If number is finite return non-zero, otherwise return zero.
+ */
+TRIO_PUBLIC int trio_isfinite(double number);
+
+TRIO_PUBLIC int trio_signbit(double number);
+
+TRIO_PUBLIC int trio_fpclassify(double number);
+
+TRIO_PUBLIC double trio_nzero(void);
+
 #ifdef __cplusplus
 }
 #endif
